This is not a usable Python package, but the name is reserved by MultiversX.

Visit https://docs.multiversx.com for information about tools and SDKs released by MultiversX for Python developers.

You can find other packages published by MultiversX here: https://pypi.org/user/MultiversX.
